import React, { useState, useEffect, useRef } from 'react'
import { Input, Button } from 'antd'
import { CompassOutlined } from '@ant-design/icons'
import IconPack from '../../IconPack'
import {
  ArcGISSceneMap,
  AutoCompleteSearch,
  Drawtool as drawTool,
  Graphic,
  GraphicsLayer,
  Point,
  geomUtils,
  SimpleLineSymbol,
  SimpleFillSymbol,
} from '@wisdom-map/arcgismap/lib'
import Drag from '../../../components/Drag'
import { isJson, isObject, mercatorToLngLat } from '../../../../utils'
import { getLocation } from '../../../../apis/process'

const DrawArea = (props) => {

  const { token, client } = window.globalConfig
  const { value, onChange, schema, addons } = props
  const { disabled, placeholder, presetValue, addressSync } = schema
  const [visible, setVisible] = useState(false)
  const [rings, setRings] = useState({})
  const viewRef = useRef(null)
  const layers = useRef(null)

  const createPaths = (view) => {
    setTimeout(() => {
      if (isJson(value)) {
        let layer = new Graphic({
          geometry: geomUtils.toGeometry(rings),
          symbol: new SimpleFillSymbol({

          }),
        })
        layers.current = new GraphicsLayer()
        layers.current.add(layer)
        view.map.add(layers.current)
      }
    }, 2000)
  }

  const getView = (viewObject) => {
    viewRef.current = viewObject
    createPaths(viewObject)
  }

  const getPoints = (view) => {
    if (view) {
      view.map.remove(layers.current)
      drawTool.activate({
        view,
        action: 'polygon',
        target: 'erroSendUpWidget',// 随便写
        toolTip: '左键选择位置',
        drawEnd: geometry => {
          setRings({ rings: geometry.rings })
          let layer = new Graphic({
            geometry: geometry,
            symbol: new SimpleFillSymbol({

            }),
          })
          layers.current = new GraphicsLayer()
          layers.current.add(layer)
          view.map.add(layers.current)
        },
        // rightClick: () => { getPoints(view, coordGetLayer) }
      })
    }
  }

  const start = () => {
    getPoints(viewRef.current)
  }

  const showMap = () => {
    setRings(isJson(value) ? JSON.parse(value) : '')
    setVisible(true)
  }

  const onCancel = () => {
    setVisible(false)
  }

  const onOk = () => {
    onChange(JSON.stringify(rings))
    setVisible(false)
  }

  useEffect(() => {
    if (addons) {
      addons.setValueByPath(addons.dataPath, presetValue)
    } else {
      onChange(presetValue)
    }
  }, [presetValue])

  return (
    <div>
      {
        !disabled ?
          <Input
            disabled={disabled}
            placeholder={placeholder}
            value={value}
            addonAfter={disabled ? null : <CompassOutlined style={{ color: 'rgba(0, 0, 0, 0.25)' }} onClick={showMap} />}
            style={{ width: '100%' }}
            onClick={showMap}
          />
          :
          <Button
            icon={<CompassOutlined style={{ color: value ? '#0092fe' : 'rgba(0, 0, 0, 0.25)' }} />}
            onClick={() => {
              if (value) {
                showMap()
              }
            }}
          >
            {value ? '查看位置' : '无位置信息'}
          </Button>
      }
      <Drag
        width={'80%'}
        title="选取坐标"
        visible={visible}
        onOk={onOk}
        onCancel={onCancel}
        cancelText={'取消'}
        okText={'确定'}
        bodyStyle={{ height: 600, overflowY: "auto", position: 'relative' }}
        destroyOnClose={true}
        {...disabled ? { footer: null } : {}}
      >
        <div style={{ height: '90%' }}>
          <Button
            style={{ position: 'absolute', zIndex: '99', right: '10px', top: '10px' }}
            type='primary'
            onClick={start}
          >
            开始绘制
          </Button>
          <ArcGISSceneMap
            getMapInfo={getView}
            widgets={[]}
            token={token}
            client={token ? client : 'sandbox'}
          />
        </div>
      </Drag >
    </div >
  )

}

export default DrawArea